tsseg.algorithms.espresso package
=================================

Hybrid: combines matrix profile, information gain and semantic density for
wearable/IoT data.

| **Type:** change point detection
| **Supervision:** semi-supervised (``n_segments``)
| **Scope:** univariate and multivariate

**Implementation:** Pure-Python translation of original MATLAB code. No licence in
original repo.

**Reference:** Deldari, Smith, Sadri & Salim (2020), IMWUT.

Submodules
----------

tsseg.algorithms.espresso.detector module
-----------------------------------------

.. automodule:: tsseg.algorithms.espresso.detector
   :members:
   :show-inheritance:
   :undoc-members:

Module contents
---------------

.. automodule:: tsseg.algorithms.espresso
   :members:
   :show-inheritance:
   :undoc-members:
